pub struct Reaction {
reaction: String,
}Expand description
A single reaction.
Fields
reaction: StringCanonical representation of reaction as a string of space-separated emojis.
Implementations
Sourceimpl Reaction
impl Reaction
Sourcepub fn new(reaction: &str) -> Self
pub fn new(reaction: &str) -> Self
Convert a &str into a Reaction.
Everything after the first whitespace is ignored.
Any short enough string is accepted as a reaction to avoid the complexity of validating emoji sequences as required by RFC 9078. On the sender side UI is responsible to provide only valid emoji sequences via reaction picker. On the receiver side, abuse of the possibility to use arbitrary strings as reactions is not different from other kinds of spam attacks such as sending large numbers of large messages, and should be dealt with the same way, e.g. by blocking the user.